c*************************************************************************
c GETACC_PRDRAG.F
c*************************************************************************
c This subroutine calculates and ADDS the POYNTING-ROBERTSON acceleration
c for the test particles in the HELIOCENTRIC frame.
c
c Input:
c   nbod		number of massive bodies
c   ntp			number of test particles
c   mass(nbod)		masses array
c   xh,yh,zh		massive bodies' heliocentric coordinates
c   xht,yht,zht		test particles' heliocentric coordinates
c   istat		status of the test paricles
c   irht		inverse distances of tp's from the Sun
c			(were already calculated earlier in getacch.f)
c Output:
c   axht,ayht,azht	new tp's accelerations in helio coord
c
c Created by:  Miroslav Broz, miroslav.broz@email.cz
c Date:  Feb 12th 2002

      subroutine getacc_prdrag(nbod,ntp,mass,xh,yh,zh,
     &     xht,yht,zht,istat,irht,axht,ayht,azht)

      include 'swift.inc'
      include 'const.inc'
      include 'pr.inc'

c...  Inputs: 
      integer nbod,ntp,istat(NTPMAX)
      real*8 mass(NPLMAX),xh(NPLMAX),yh(NPLMAX),zh(NPLMAX)
      real*8 xht(NTPMAX),yht(NTPMAX),zht(NTPMAX)

c...  Outputs:
      real*8 axht(NTPMAX),ayht(NTPMAX),azht(NTPMAX)
                
c...  Internals:
      integer i
      real*8 irht(NTPMAX)
      real*8 nx,ny,nz, c_vn, K

c  common block /velocities/ (these are HELIOCENTRIC)
      real*8 vxht(NTPMAX),vyht(NTPMAX),vzht(NTPMAX)
      common/velocities/vxht,vyht,vzht

c...  Constants:
      real*8 c
      parameter(c = cv/AU*day)	! speed of light [AU.day^(-1)]

c----
c...  Executable code 

!$OMP PARALLEL DO
!$OMP&  PRIVATE (i, nx, ny, nz, c_vn, K)
!$OMP&  SHARED (ntp, istat, xht, yht, zht, irht, vxht, vyht, vzht,
!$OMP&    pr, axht, ayht, azht)
      do i = 1, ntp
        if (istat(i).eq.0) then		! only active particles
          nx = xht(i)*irht(i)
          ny = yht(i)*irht(i)
          nz = zht(i)*irht(i)
          c_vn = c - (vxht(i)*nx + vyht(i)*ny + vzht(i)*nz)
          K = pr(i) * irht(i)*irht(i)

          axht(i) = axht(i) + K * (c_vn*nx - vxht(i))
          ayht(i) = ayht(i) + K * (c_vn*ny - vyht(i))
          azht(i) = azht(i) + K * (c_vn*nz - vzht(i))

        endif
      enddo
!$OMP END PARALLEL DO

      return
      end      ! getacc_prdrag

c---------------------------------------------------------------------

