c**********************************************************************
c IO_INIT_YARKO.F
c**********************************************************************
c Read yarko-related and reorintation parameters
c
c Input:
c  infile	name of the yarko-data input file
c  nbod		number of massive bodies (including the Sun)
c  ntp		number of test particles
c
c  in common block /radii/
c  radius(NTPMAX)	radii of TP's from io_init_th.f subroutine
c
c Output:
c  dtreorient		reorientation time step
c  tau_reor(NTPMAX)	mean reorientation times
c  tau_disr(NTPMAX)	mean disruption times
c  tau_yorp(NTPMAX)	mean YORP "reorientation" times
c  iflgchk		if bits 6 or 7 are set, then write *.out file
c
c  in common block /yarko/
c  k_seasonal		number of iterations
c
c  in common block /hill/
c  hill_scale		individual scaling of Hill spheres
c
c Remarks: 
c Author: Miroslav Broz, miroslav.broz@email.cz
c Date: Apr 18th 2001

      subroutine io_init_yarko(infile,nbod,ntp,dtreorient,
     &  tau_reor,tau_disr,tau_yorp,a_mean1,a_mean2,iflgchk)

      include 'swift.inc'
      include 'yarko.inc'

c  input
      character*(*) infile
      integer nbod,ntp,iflgchk

c  output
      real*8 dtreorient,tau_reor(NTPMAX),tau_disr(NTPMAX),
     :  tau_yorp(NTPMAX),a_mean1,a_mean2

c  Hill spheres scaling factors (see modified rmvs3_chk.f subroutine)
      real*8 hill_scale(NPLMAX)
      common /hill/ hill_scale

c  radii of TP's from io_init_th subroutine (for calculation of tau's)
      real*8 radius(NTPMAX)
      common/radii/radius

c  internal
      integer i,ierr
      real*8 tau_reor0,tau_disr0,tau_yorp0
      logical write_reorient,write_disrupt

c  main ----------------------------------------------------------
      write(*,*) 'Yarko-data file called ',infile
      call io_open(7,infile,'old','formatted',ierr)

      read(7,*,err=99,end=99) k_seasonal
      if(k_seasonal.gt.MAXk_seasonal) then
        write(*,*) ' SWIFT ERROR: in io_init_th'
        write(*,*) '     Number of iterations k_seasonal higher than ',
     :    MAXk_seasonal
        call util_exit(1)
      endif

      read(7,*,err=99,end=99) (hill_scale(i),i=2,nbod)

      read(7,*,err=99,end=99) dtreorient
      read(7,*,err=99,end=99) tau_reor0
      read(7,*,err=99,end=99) tau_disr0
      read(7,*,err=99,end=99) write_reorient
      read(7,*,err=99,end=99) write_disrupt
      read(7,*,err=99,end=99) a_mean1, a_mean2
      read(7,*,err=99,end=99) tau_yorp0

c  dtreorient, tau_reor0, tau_disr0 are given in yr
      dtreorient=dtreorient*365.25d0
c
c  expecting dependence of reorientation and disruption times tau_reor
c  on radius R in form tau*sqrt(R [m]) and tau*(R [km])^2 for YORP
c
      do i=1,ntp
        tau_reor(i)=365.25d0*tau_reor0*sqrt(radius(i))
        tau_disr(i)=365.25d0*tau_disr0*sqrt(radius(i))
        tau_yorp(i)=365.25d0*tau_yorp0*(radius(i)/1000.0d0)**2
      enddo

      if (write_reorient) iflgchk=ibset(iflgchk,6)
      if (write_disrupt) iflgchk=ibset(iflgchk,7)

      close(unit = 7)
      write(*,*) ' '
      return

99    continue
      write(*,*) 'Error reading file',infile
      stop

      end    ! io_init_yarko.f
c-----------------------------------------------------------------

