c**********************************************************************
c REORIENT.F
c**********************************************************************
c Reorient the spin axes of test particles.
c
c Input:
c  t			time
c  ntp			number of test particles
c  s(3,NTPMAX)		array of spin axes orientations /yarko/
c  dtreorient		reorientation time step
c  tau(NTPMAX)		mean reorientation times
c  idum			initial number for ran1
c
c Output:
c  s(3,NTPMAX)	new orientations of the spin axes /yarko/
c
c Remarks: 
c Author: Miroslav Broz, miroslav.broz@email.cz
c Date: Apr 18th 2001

      subroutine reorient(t,ntp,dt,tau,idum,reoriented)

      include 'swift.inc'
      include 'yarko.inc'

c  input
      integer ntp,idum
      real*8 t,dt,tau(NTPMAX)
      logical reoriented

c  internal
      integer i
      real*8 s1,coss2,sins2,p,p_reor
      real ran1

c  main
      reoriented = .false.

c  ignore reorientation if tau < 0
      if (tau(1).lt.0) return

      do i=1,ntp
        p_reor = 1 - exp(-dt/tau(i))
        p=1.0d0*ran1(idum)
        if (p.lt.p_reor) then
          reoriented = .true.
          s1=TWOPI*ran1(idum)
          sins2=2.0d0*ran1(idum)-1.0d0
c  sins2 = (-1.,1.) !!!
c          sins2=coss2/abs(coss2)*sqrt(1-coss2**2)
          coss2 = sqrt(1-sins2**2)
          s(1,i)=cos(s1)*coss2
          s(2,i)=sin(s1)*coss2
          s(3,i)=sins2
        endif
      enddo

      return
      end	! reorient.f
c-----------------------------------------------------------------

